@@ -21,13 +21,17 @@ class ExecutedChecksResultListTest(BasicTestingCase):
                 configured_name='first',
                 output='Test',
                 exit_status=False,
-                hooks_output=''
+                hooks_output='',
+                description='First in test',
+                is_silenced=False
             ))
             results.add('second', ExecutedCheckResult(
                 configured_name='second',
                 output='Test',
                 exit_status=True,
-                hooks_output=''
+                hooks_output='',
+                description='Second in test',
+                is_silenced=False
             ))
 
             self.assertFalse(results.is_global_status_success())
@@ -38,13 +42,17 @@ class ExecutedChecksResultListTest(BasicTestingCase):
                 configured_name='first',
                 output='Test',
                 exit_status=True,
-                hooks_output=''
+                hooks_output='',
+                description='First in test',
+                is_silenced=False
             ))
             results.add('second', ExecutedCheckResult(
                 configured_name='second',
                 output='Test',
                 exit_status=True,
-                hooks_output=''
+                hooks_output='',
+                description='Second in test',
+                is_silenced=False
             ))
 
             self.assertTrue(results.is_global_status_success())
@@ -55,13 +63,17 @@ class ExecutedChecksResultListTest(BasicTestingCase):
                 configured_name='first',
                 output='Test',
                 exit_status=False,
-                hooks_output=''
+                hooks_output='',
+                description='First in test',
+                is_silenced=False
             ))
             results.add('second', ExecutedCheckResult(
                 configured_name='second',
                 output='Test',
                 exit_status=False,
-                hooks_output=''
+                hooks_output='',
+                description='Second in test',
+                is_silenced=False
             ))
 
             self.assertFalse(results.is_global_status_success())
